# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.15] - 2022-09-24
### Added
- Phemex

## [1.0.14] - 2022-08-07
### Added
- Bitget

## [1.0.13] - 2022-06-05
### Updated
- Renamed OKEx into OKX

## [1.0.12] - 2021-10-27
### Added
- Bybit spot and future
- Ascendex

### Fixed 
- OKEx tests

## [1.0.11] - 2021-08-31
### Added
- Huobi pro

## [1.0.10] - 2021-08-27
### Added
- Huobi ids

## [1.0.9] - 2021-08-25
### Added
- GateIO ids

## [1.0.8] - 2021-08-15
### Updated
- Binance error messages

## [1.0.7] - 2021-08-08
### Fix
- Check credentials in all exchange is_valid_account()

## [1.0.6] - 2021-08-02
### Added
- FTX ids
- OKEx ids

## [1.0.5] - 2021-08-02
### Added
- Referral id

## [1.0.4] - 2021-07-12
### Fixed
- Binance client id generator

## [1.0.3] - 2021-07-08
### Added
- Account credentials check on is_valid_account
- ExchangeAuthError

## [1.0.2] - 2021-06-26
### Added
- TimeSyncError

## [1.0.1] - 2021-06-23
### Added
- Binance ids

## [1.0.0] - 2021-06-06
### Project creation
